@@ -6,7 +6,7 @@ use LWP::UserAgent;
 #use MooseX::Types::URI qw( Uri ); # this doesn't work for some reason
 use WWW::FMyLife::Item;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 has 'username' => ( is => 'rw', isa => 'Str' );
 has 'password' => ( is => 'rw', isa => 'Str' );
@@ -15,6 +15,7 @@ has 'language' => ( is => 'rw', isa => 'Str', default => 'en'       );
 has 'token'    => ( is => 'rw', isa => 'Str', default => q{}        );
 has 'key'      => ( is => 'rw', isa => 'Str', default => 'readonly' );
 
+# XXX: is there a point to this? is this wannabe caching?
 has 'pages'    => ( is => 'rw', isa => 'Int' );
 
 has 'api_url'  => (
@@ -54,8 +55,45 @@ sub credentials {
     $self->password ( $pass );
 }
 
+sub top {
+    my ( $self, $opts ) = @_;
+    my @items = $self->_parse_options( $opts, 'top' );
+    return @items;
+}
+
+sub top_day {
+    my ( $self, $opts ) = @_;
+    my @items = $self->_parse_options( $opts, 'top' );
+    return @items;
+}
+
+sub top_week {
+    my ( $self, $opts ) = @_;
+    my @items = $self->_parse_options( $opts, 'top' );
+    return @items;
+}
+
+sub top_month {
+    my ( $self, $opts ) = @_;
+    my @items = $self->_parse_options( $opts, 'top' );
+    return @items;
+}
+
 sub last {
     my ( $self, $opts ) = @_;
+    my @items = $self->_parse_options( $opts, 'last' );
+    return @items;
+}
+
+sub random {
+    my $self = shift;
+    my $xml  = $self->_fetch_data('/view/random');
+    my $item = $self->_parse_item_as_object($xml);
+    return $item;
+}
+
+sub _parse_options {
+    my ( $self, $opts, $add_url ) = @_;
     my ( $as,   $page );
 
     if ( ref $opts eq 'HASH' ) {
@@ -74,8 +112,22 @@ sub last {
         data   => sub { return $self->_parse_items_as_data  (@_) },
     );
 
+    my $xml = $self->_fetch_data("/view/$add_url/$page");
+
+    $xml || return;
+
+    $self->pages( $xml->{'pages'} );
+
+    my @items = $types{$as}->($xml);
+
+    return @items;
+}
+
+sub _fetch_data {
+    my ( $self, $add_to_url ) = @_;
+
     my $res = $self->agent->post(
-        $self->api_url . "/view/last/$page", {
+        $self->api_url . $add_to_url, {
             key      => $self->key,
             language => $self->language,
         },
@@ -88,7 +140,7 @@ sub last {
     if ( ! $res->is_success ) {
         $self->error(1);
         $self->module_error( $res->status_line );
-        return undef;
+        return;
     }
 
     my $xml = XMLin( $res->decoded_content );
@@ -99,18 +151,28 @@ sub last {
 
         $self->error(1);
         $self->fml_errors($array_errors);
-        return undef;
+        return;
     }
 
-    $self->pages( $xml->{'pages'} );
+    return $xml;
+}
 
-    # return parsed last quotes
-    my @items = $types{$as}->($xml);
+sub _parse_item_as_object {
+    # this parses a single item
+    my ( $self, $xml ) = @_;
 
-    return @items;
+    my %item_data = %{ $xml->{'items'}{'item'} };
+    my $item      = WWW::FMyLife::Item->new();
+
+    foreach my $attr ( keys %item_data ) {
+        $item->$attr( $item_data{$attr} );
+    }
+
+    return $item;
 }
 
 sub _parse_items_as_object {
+    # this parses multiple items
     my ( $self, $xml ) = @_;
     my @items;
 
@@ -152,41 +214,35 @@ WWW::FMyLife - Obtain FMyLife.com anectodes via API
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 SYNOPSIS
 
 THIS MODULE IS STILL UNDER INITIAL DEVELOPMENT! BE WARNED!
 
-This module fetches FMyLife.com (FML) anecdotes, comments, votes and more via API, comfortably.
+This module fetches FMyLife.com (FML) anecdotes, comments, votes and more via API, comfortably and in an extensible manner.
 
     use WWW::FMyLife;
 
-    my $fml    = WWW::FMyLife->new();
-    print map { "Items: $_\n" } $fml->last();
+    my $fml = WWW::FMyLife->new();
+    print map { "Items: $_\n" } $fml->last( { as => text' } );
 
-    my @items = $fml->last();
+    my @items = $fml->top_daily();
     foreach my $item (@items) {
         my $item_id      = $item->id;
         my $item_content = $item->content;
         print "[$item_id] $item_content\n";
     }
 
-    my @text_items = $fml->last( { as => 'text' } );
-    print "Items:\n", join "\n", @text_items;
+    print $fml->random()->text, "\n";
     ...
 
-
 =head1 EXPORT
 
 This module exports nothing.
 
 =head1 METHODS
 
-=head2 Working
-
-Right now the only thing working and tested properly is the last() method
-
 =head2 last()
 
 Fetches the last quotes. Can accept a hashref that indicates the formatting:
@@ -214,6 +270,34 @@ And options can be mixed:
 
     my @not_so_last = $fml->last( { as => 'text', page => 50 } );
 
+=head2 random
+
+This method gets a single random quote as an object.
+
+=head2 top
+
+This method works the same as the last() method, only it fetches the top quotes.
+
+This method, as for its variations, can format as an object, text or data.
+
+=head2 top_day
+
+This method works the same as the last() method, only it fetches the top quotes.
+
+This specific variant fetches the top anecdotes from the last day.
+
+=head2 top_week
+
+This method works the same as the last() method, only it fetches the top quotes.
+
+This specific variant fetches the top anecdotes from the last week.
+
+=head2 top_month
+
+This method works the same as the last() method, only it fetches the top quotes.
+
+This specific variant fetches the top anecdotes from the last month.
+
 =head2 credentials( $username, $password ) (NOT YET FULLY IMPLEMENTED)
 
 WARNING: THIS HAS NOT YET BEEN IMPLEMENTED.
